=======
History
=======

0.2.* (2022-11-22)
------------------

* First releases to PyPI
* Still under development but usable codebase for training and prediction
* Use alongside icenet-pipeline and icenet-notebooks
* Proper releases will follow >=0.2.1, otherwise alpha versioned for the mo

0.1.* (2021-2022)
-----------------

* These releases are pre-public release and should not be used except by the
  BAS and Alan Turing Institute development teams.
